@@ -405,7 +405,7 @@ AU_UN<-function(M,sep){
   })
   AFFL=unlist(AFFL)
   M$AU_UN=AFFL
-  if (M$DB[1]=="ISI" & "C3" %in% names(M)){
+  if (M$DB[1] %in% c("ISI", "OPENALEX") & "C3" %in% names(M)){
     M$AU_UN[!is.na(M$C3) & M$C3!=""] <- M$C3[!is.na(M$C3) & M$C3!=""]
   }
   M$AU_UN=gsub("\\\\&","AND",M$AU_UN)
